@@ -77,18 +77,17 @@ class BaseDocument(object):
     @return_future
     def save(self, callback, alias=None):
         '''
-        Saves a new instance of this document.
-
-        Usage::
-
-            doc = MyDocument(some_property="value")
-            doc.save(callback)
-
-            def callback(instance):
-                # do something with instance
+        Creates or updates the current instance of this document.
         '''
         self.objects.save(self, callback=callback, alias=alias)
 
+    @return_future
+    def delete(self, callback, alias=None):
+        '''
+        Deletes the current instance of this Document.
+        '''
+        self.objects.remove(instance=self, callback=callback, alias=alias)
+
     def handle_load_reference(self, callback, references, reference_count, values_collection, field_name):
         def handle(*args, **kw):
             values_collection[field_name] = args[0]
