@@ -64,6 +64,33 @@ class QuerySet(object):
             else:
                 self.coll(alias).insert(doc, callback=self.handle_save(document, callback))
 
+    @return_future
+    def delete(self, callback=None, alias=None):
+        '''
+        Removes all instance of this document that match the specified filters (if any).
+        '''
+
+        self.remove(callback=callback, alias=alias)
+
+    def handle_remove(self, callback):
+        def handle(*args, **kw):
+            callback(args[0]['n'])
+
+        return handle
+
+    def remove(self, instance=None, callback=None, alias=None):
+        if callback is None:
+            raise RuntimeError("The callback argument is required")
+
+        if instance is not None:
+            if hasattr(instance, '_id') and instance._id:
+                self.coll(alias).remove(instance._id, callback=self.handle_remove(callback))
+        else:
+            if self._filters:
+                self.coll(alias).remove(self._filters, callback=self.handle_remove(callback))
+            else:
+                self.coll(alias).remove(callback=self.handle_remove(callback))
+
     def handle_auto_load_references(self, doc, callback):
         def handle(*args, **kw):
             if len(args) > 0:
@@ -95,15 +122,6 @@ class QuerySet(object):
         Gets a single item of the current queryset collection using it's id.
 
         In order to query a different database, please specify the `alias` of the database to query.
-
-        Usage::
-
-            User.objects.get(user_id, callback=handle_get_user)
-
-            def handle_get_user(instance):
-                # do something with instance
-                # instance is None if user not found
-                pass
         '''
         if id is None and not kwargs:
             raise RuntimeError("Either an id or a filter must be provided to get")
@@ -223,14 +241,5 @@ class QuerySet(object):
     def count(self, callback, alias=None):
         '''
         Returns the number of documents in the collection that match the specified filters (if any).
-
-        Usage::
-
-            User.objects.count(callback=handle_count)
-
-            def handle_count(result):
-                # do something with result
-                # result is 0 if no users found
-                pass
         '''
         self._get_find_cursor(alias=alias).count(callback=self.handle_count(callback))
